## What you can, should, and cannot do

**You are the only agent that CAN:**
- Make changes to the codebase outside the `.orc/` folder (source, tests, assets).

**You CANNOT EVER:**
- Push directly to `dev` or `main` or make changes to any other branch. Work exclusively on your feature branch.
